/*--------------------------------------------------------------
  
 File        : pde_heatflow2D.cpp
 Description : A simple Heat flow on 2D images
 Author      : Tschumperl David
 Institution : ODYSSEE, INRIA Sophia Antipolis.
 Contact     : David.Tschumperle@sophia.inria.fr
 Date        : 03/12/2003

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

-------------------------------------------------------------*/

#include "../CImg.h"

int main(int argc,char **argv)
{
  cimg_usage("A simple Heat Flow on 2D images");
  CImg<> img = cimg_option("-i","img/milla.ppm","Input image"), veloc(img,false);
  const double dt = cimg_option("-dt",30.0,"Adapting time step");
  img.noise(cimg_option("-ng",0.0,"Add gaussian noise"),0);
  img.noise(cimg_option("-nu",0.0,"Add uniform noise"),1);
  img.noise(cimg_option("-ns",0.0,"Add Salt&Pepper noise"),2);
  CImgDisplay disp(img,"heat flow 2D");
  CImgStats stats;
  CImg_3x3(I,float);

  for (uint iter=0; !disp.closed && disp.key!=cimg::keyQ; iter++) {
    fprintf(stderr,"iter = %d         \r",iter); fflush(stderr);
    cimg_mapV(img,k) cimg_map3x3(img,x,y,0,k,I) veloc(x,y,k) = Inc+Ipc+Icn+Icp-4*Icc;
    stats = veloc.stats(0);
    const double xdt = dt/(stats.max-stats.min);
    img += veloc*xdt;
    img.display(disp);
  }

  exit(0);
  return 0;
}
