/*-----------------------------------------------------------------------
  
    File        : tutorial.cpp
    Description : View intensity profile on an image
                  (quite similar to the tutorial source on the CImg web page)
    Author      : Tschumperl David
    Institution : ODYSSEE, INRIA Sophia Antipolis.
    Contact     : David.Tschumperle@sophia.inria.fr
    Date        : 03/12/2003

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    ---------------------------------------------------------------------*/

#include "../CImg.h"
// The lines below are not necessary in your own code, it simply allows 
// the source compilation with compilers that do not respect the C++ standart.
#if ( defined(_MSC_VER) && _MSC_VER<=1200 ) || defined(__DMC__)
#define std
#endif

int main(int argc,char **argv) {
  cimg_usage("View intensity profile of an image along the X axis");
  const char* file_i = cimg_option("-i","img/parrot_original.ppm","Input image");
  const double sigma = cimg_option("-blur",1,"Variance of gaussian pre-blurring");
  CImg<uchar> image(file_i), visu(500,400,1,3,0);
  const uchar red[3]={255,0,0}, green[3]={0,255,0}, blue[3]={0,0,255}, white[3]={255,255,255};
  uint hatch=50;
  image.blur(sigma);
  CImgDisplay main_disp(image,"Move mouse over the image"),
    draw_disp(visu,"Intensity profile of the X-axis");
  while (!main_disp.closed && !draw_disp.closed) {
    main_disp.wait_sync(20);
    if (main_disp.mousex>=0) {
      const int x = main_disp.mousex*visu.dimx()/image.dimx(), y = main_disp.mousey;
      visu.fill(0).draw_line(x,0,x,visu.dimy()-1,white,hatch+=0x1000).
        draw_plot(image.get_sprite(0,y,0,0,image.dimx()-1,y,0,0),red,0,256).
        draw_plot(image.get_sprite(0,y,0,1,image.dimx()-1,y,0,1),green,0,256).
        draw_plot(image.get_sprite(0,y,0,2,image.dimx()-1,y,0,2),blue,0,256).
        draw_text(5,5,white,NULL,NULL,"x=%d, y=%d",main_disp.mousex,main_disp.mousey).display(draw_disp);
    } else
      CImg<uchar>(visu,false).fill(0).
        draw_text(visu.dimx()/2-110,visu.dimy()/2-5,"Mouse pointer is outside the image",white).display(draw_disp);
  }
  exit(0);
  return 0;
}
